//@line 36 "/home/cltbld/build/maemo-1.9.2-l10n-release/releases/l10n-mozilla-1.9.2/pl/mobile/mobile-l10n.js"

//@line 38 "/home/cltbld/build/maemo-1.9.2-l10n-release/releases/l10n-mozilla-1.9.2/pl/mobile/mobile-l10n.js"

pref("general.useragent.locale", "pl");
